==> leaflet-2.1.22.tar.gz: leaflet/modules/leaflet_markercluster/leaflet_markercluster.drupal.js <==
/**
 * We are overriding the adding features functionality of the Leaflet module.
 */

(function ($) {
  Drupal.Leaflet.prototype.add_features = function (mapid, features, initial) {

    var leaflet_markercluster_options = this.settings.leaflet_markercluster.options && this.settings.leaflet_markercluster.options.length > 0 ? JSON.parse(this.settings.leaflet_markercluster.options) : {};
    var leaflet_markercluster_inlcude_path = this.settings.leaflet_markercluster.include_path;

    var cluster_layer = new L.MarkerClusterGroup(leaflet_markercluster_options);
    var collections_cluster_layers = {};
    for (var i = 0; i < features.length; i++) {
      var feature = features[i];
      var lFeature;

      // dealing with a layer group
      if (feature.group) {
        var lGroup = this.create_feature_group(feature);
        for (var groupKey in feature.features) {
          var groupFeature = feature.features[groupKey];
          lFeature = this.create_feature(groupFeature);
          if (lFeature !== undefined) {
            if (lFeature.setStyle) {
              feature.path = feature.path ? (feature.path instanceof Object ? feature.path : JSON.parse(feature.path)) : {};
              lFeature.setStyle(feature.path);
            }
            if (groupFeature.popup) {
              lFeature.bindPopup(groupFeature.popup);
            }
            lGroup.addLayer(lFeature);
          }
        }

        // @todo we need to correctly handle the groups here
        cluster_layer.addLayer(lGroup);
      }
      else {
        lFeature = this.create_feature(feature);
        if (lFeature !== undefined) {

          if (lFeature.setStyle) {
            feature.path = feature.path ? (feature.path instanceof Object ? feature.path : JSON.parse(feature.path)) : {};
            lFeature.setStyle(feature.path);
          }

          // If the Leaflet feature is extending the Path class (Polygon,
          // Polyline, Circle) don't add it to Markercluster.
          if (lFeature.setStyle && !leaflet_markercluster_inlcude_path) {
            this.lMap.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup);
            }
          }
          else {
            // this.lMap.addLayer(lFeature);
            cluster_layer.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup);
            }
          }
        }
      }

      // Allow others to do something with the feature that was just added to the map
      $(document).trigger('leaflet.feature', [lFeature, feature, this]);
    }

    // Add all markers to the map
    this.lMap.addLayer(cluster_layer)

    // Allow plugins to do things after features have been added.
    $(document).trigger('leaflet.features', [initial || false, this])
  };

})(jQuery);

==> leaflet-2.2.1.tar.gz: leaflet/modules/leaflet_markercluster/leaflet_markercluster.drupal.js <==
/**
 * We are overriding the adding features functionality of the Leaflet module.
 */

(function ($) {
  Drupal.Leaflet.prototype.add_features = function (mapid, features, initial) {
    const leaflet_markercluster_options = this.settings.leaflet_markercluster.options && this.settings.leaflet_markercluster.options.length > 0 ? JSON.parse(this.settings.leaflet_markercluster.options) : {};
    const leaflet_markercluster_inlcude_path = this.settings.leaflet_markercluster.include_path;

    const cluster_layer = new L.MarkerClusterGroup(leaflet_markercluster_options);
    for (let i = 0; i < features.length; i++) {
      let feature = features[i];
      let lFeature;

      // dealing with a layer group
      if (feature.group) {
        var lGroup = this.create_feature_group(feature);
        for (var groupKey in feature.features) {
          let groupFeature = feature.features[groupKey];
          lFeature = this.create_feature(groupFeature);
          if (lFeature !== undefined) {
            if (lFeature.setStyle) {
              feature.path = feature.path ? (feature.path instanceof Object ? feature.path : JSON.parse(feature.path)) : {};
              lFeature.setStyle(feature.path);
            }
            if (groupFeature.popup) {
              lFeature.bindPopup(groupFeature.popup);
            }
            lGroup.addLayer(lFeature);
          }
        }

        // Correctly handle the groups here
        this.add_overlay(feature.label, lGroup, false, mapid);
      }
      else {
        lFeature = this.create_feature(feature);
        if (lFeature !== undefined) {

          if (lFeature.setStyle) {
            feature.path = feature.path ? (feature.path instanceof Object ? feature.path : JSON.parse(feature.path)) : {};
            lFeature.setStyle(feature.path);
          }

          // If the Leaflet feature is extending the Path class (Polygon,
          // Polyline, Circle) don't add it to Markercluster.
          if (lFeature.setStyle && !leaflet_markercluster_inlcude_path) {
            this.lMap.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup);
            }
          }
          else {
            // this.lMap.addLayer(lFeature);
            cluster_layer.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup);
            }
          }
        }
      }

      // Allow others to do something with the feature that was just added to the map
      $(document).trigger('leaflet.feature', [lFeature, feature, this]);
    }

    // Add all markers to the map
    this.lMap.addLayer(cluster_layer)

    // Allow plugins to do things after features have been added.
    $(document).trigger('leaflet.features', [initial || false, this])
  };

})(jQuery);
